/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.graphics;

import java.awt.Graphics2D;

public class GC {
	
	Drawable drawable;
	
	GCData gcData;

	Color foreground;
	
	Color background;

	public GC(Drawable drawable) {
		this.drawable = drawable;
		this.gcData = new GCData();
		drawable.internal_new_GC(gcData);
	}

	/* not public */
	public GC(Graphics2D g) {
		this.gcData = new GCData();
		this.gcData.g = g;
	}

	public void dispose() {
		if (drawable != null) {
			drawable.internal_dispose_GC(0, gcData);
		}
	}

	public void setForeground(Color color) {
		foreground = color;
	}

	public void setBackground(Color color) {
		background = color;
	}

	public void drawRectangle(int x, int y, int width, int height) {
		setupForegroundColor();
		gcData.g.drawRect(x, y, width - 1, height - 1);
	}

	public void fillRectangle(Rectangle rectangle) {
		fillRectangle(rectangle.x, rectangle.y, rectangle.width, rectangle.height);
	}

	public void fillRectangle(int x, int y, int width, int height) {
		setupBackgroundColor();
		gcData.g.fillRect(x, y, width, height);
	}
	
	public void drawImage(Image image, int x, int y) {
		gcData.g.drawImage(image.image, x, y, null);
	}

	public FontMetrics getFontMetrics() {
		return new FontMetrics(gcData.g.getFontMetrics());
	}

	public void drawString(String string, int x, int y) {
		setupForegroundColor();
		
		gcData.g.drawString(string, x, y + gcData.g.getFontMetrics().getAscent());
	}

	private void setupForegroundColor() {
		gcData.g.setColor(new java.awt.Color(foreground.red, foreground.green, foreground.blue));
	}
	
	private void setupBackgroundColor() {
		gcData.g.setColor(new java.awt.Color(background.red, background.green, background.blue));
	}

	public void drawImage(Image image, int x, int y, int width, int height, int x2, int y2, int width2, int height2) {
		// TODO Auto-generated method stub
	}

	
	



}
