/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.graphics;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.image.BufferedImage;

import javax.swing.Icon;
import javax.swing.ImageIcon;

public class Image implements Drawable {
	
	BufferedImage image;

	public Image(Device device, int width, int height) {
		image = new BufferedImage(width, height, BufferedImage.TYPE_INT_ARGB);
	}

	public Image(Device device, ImageData data) {
		image = new BufferedImage(data.width, data.height, BufferedImage.TYPE_INT_ARGB);
		Graphics2D g = image.createGraphics();
		for (int y = 0; y < data.height; y++) {
			for (int x = 0; x < data.width; x++) {
				int p = data.getPixel(x, y);
				RGB rgb = data.palette.getRGB(p);
				g.setColor(new Color(rgb.red, rgb.blue, rgb.green));
				g.fillRect(x, y, 1, 1);
			}
		}
		g.dispose();
	}

	public Image(Device device, ImageData source, ImageData mask) {
		// TODO Auto-generated constructor stub
		this(device, source);
	}

	public boolean isDisposed() {
		return image == null;
	}

	public Rectangle getBounds() {
		return new Rectangle(0, 0, image.getWidth(), image.getHeight());
	}

	public void dispose() {
		image.flush();
		image = null;
	}
	
	public Icon _icon() {
		return new ImageIcon(image);
	}

	public int internal_new_GC(GCData data) {
		data.g = image.createGraphics();
		return 0;
	}

	public void internal_dispose_GC(int handle, GCData data) {
		data.g.dispose();
	}

}
