/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.program;

import java.io.IOException;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.ImageData;
import org.eclipse.swt.graphics.PaletteData;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.internal.Compatibility;

public final class Program {

	/** A crude file image, created from memory by imagining the bits. */
	private static final ImageData imageData = new ImageData(
			16, 16, 1, 
			new PaletteData(new RGB[] { new RGB(255, 255, 255), new RGB(0, 0, 0) }),
			2,
			new byte[] {
				(byte) 0x00, (byte) 0x00,
				(byte) 0x7f, (byte) 0xe0,
				(byte) 0x7f, (byte) 0xf0,
				(byte) 0x7f, (byte) 0xf8,
				(byte) 0x7f, (byte) 0xfc,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x7f, (byte) 0xfe,
				(byte) 0x00, (byte) 0x00
			});
	
	private final String command;

	private Program(String command) {
		this.command = command;
	}

	/**
	 * Returns the progam associated with the given extension.
	 * THIS IS A WINDOWS-ONLY SOLUTION.
	 */
	public static Program findProgram(String extension) {
		if (extension == null) {
			SWT.error(SWT.ERROR_NULL_ARGUMENT);
		}
		if (extension.length() == 0) {
			return null;
		}
		if (extension.charAt(0) != '.') {
			extension = "." + extension; //$NON-NLS-1$
		}
		String command = null;
		if (".txt".equals(extension)) {
			command = "notepad.exe \"%1\"";
		}
		return new Program(command);
	}

	/**
	 * Launches the application associated with the filename.
	 * THIS IS A WINDOWS-ONLY SOLUTION.
	 */
	public static boolean launch(String fileName) {
		if (fileName == null) {
			SWT.error(SWT.ERROR_NULL_ARGUMENT);
		}
		try {
			Compatibility.exec("rundll32 SHELL32.DLL,ShellExec_RunDLL " + fileName);
		} catch (IOException e) {
			return false;
		}
		return true;
	}

	/**
	 * Returns the program's image data.
	 */
	public ImageData getImageData() {
		return imageData;
	}

	public boolean execute(String fileName) {
		if (fileName == null) {
			SWT.error(SWT.ERROR_NULL_ARGUMENT);
		}
		boolean quote = true;
		String prefix = command, suffix = ""; //$NON-NLS-1$
		int index = command.indexOf ("%1"); //$NON-NLS-1$
		if (index != -1) {
			int count=0;
			int i=index + 2, length = command.length ();
			while (i < length) {
				if (command.charAt (i) == '"') count++;
				i++;
			}
			quote = count % 2 == 0;
			prefix = command.substring (0, index);
			suffix = command.substring (index + 2, length);
		}
		if (quote) fileName = " \"" + fileName + "\""; //$NON-NLS-1$ //$NON-NLS-2$
		try {
			Compatibility.exec(prefix + fileName + suffix);
		} catch (IOException e) {
			return false;
		}
		return true;
	}

	public String getName() {
		// TODO Auto-generated method stub
		return "some type";
	}

}
