/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.AbstractButton;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JRadioButton;
import javax.swing.JToggleButton;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Image;

public class Button extends Control {
	
	AbstractButton button;

	public Button(Composite composite, int style) {
		super(composite, style);
		if (_isSet(style, SWT.PUSH)) {
			button = new JButton();
		} else if (_isSet(style, SWT.TOGGLE)) {
			button = new JToggleButton();
		} else if (_isSet(style, SWT.CHECK)) {
			button = new JCheckBox();
		} else if (_isSet(style, SWT.RADIO)) {
			button = new JRadioButton();
		} else {
			throw new UnsupportedOperationException();
		}
		button.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				sendEvent(SWT.Selection);
			}
		});
		composite._add(this);
	}

	public void setText(String text) {
		if (text == null) {
			button.setText(null);
		} else {
			int a = text.indexOf('&');
			if (a != -1) {
				text = text.substring(0, a) + text.substring(a + 1);
				button.setMnemonic(text.charAt(a));
			}
			button.setText(text);
			button.setDisplayedMnemonicIndex(a);
			button.setIcon(null);
		}
	}

	public void setImage(Image image) {
		if (image == null) {
			button.setIcon(null);
			button.setMnemonic(0);
		} else {
			button.setText(null);
			button.setIcon(image._icon());
		}
	}


	
	public void setSelection(boolean selected) {
		button.setSelected(selected);
	}
	
	@Override
	Container _control() {
		return button;
	}

	public void addSelectionListener(SelectionListener listener) {
		addListener(SWT.Selection, new TypedListener(listener));
	}

	public boolean getSelection() {
		return button.isSelected();
	}

	public void setAlignment(int alignment) {
		// TODO Auto-generated method stub
		
	}

}