/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Container;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import javax.swing.AbstractListModel;
import javax.swing.ComboBoxModel;
import javax.swing.JComboBox;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;

public class Combo extends Control {
	
	SWTComboBoxModel model;
	
	JComboBox combo;
	
	
	public Combo(Composite parent, int style) {
		super(parent, style);
		combo = new JComboBox(model = new SWTComboBoxModel());
		combo.addKeyListener(new KeyAdapter() {
			@Override
			public void keyTyped(KeyEvent evt) {
				if (evt.getKeyChar() == KeyEvent.VK_ENTER) {
					Event e = new Event();
					e.type = SWT.DefaultSelection;
					e.display = display;
					e.widget = Combo.this;
					sendEvent(e);
				}
			}
		});
		parent._add(this);
	}

	public String[] getItems() {
		return model.getItems();
	}

	public void setItems(String[] strings) {
		model.setItems(strings);
	}
	
	public void add(String string) {
		model.add(string);
	}

	public void select(int index) {
		combo.setSelectedIndex(index);
	}

	public int getSelectionIndex() {
		return combo.getSelectedIndex();
	}

	

	/* SWT thinks that size includes the drop down */
	@Override
	public void setSize(int x, int y) {
		super.setSize(x, combo.getPreferredSize().height);
	}

	@Override
	Container _control() {
		return combo;
	}
	
	class SWTComboBoxModel extends AbstractListModel implements ComboBoxModel {
		private static final long serialVersionUID = 7179594266192155071L;

		private Object selected;
		
		private List<String> items = new ArrayList<String>();

		public void setSelectedItem(Object anItem) {
			selected = anItem;
			fireContentsChanged(this, -1, -1);
		}

		public Object getSelectedItem() {
			return selected;
		}

		public int getSize() {
			return items.size();
		}

		public Object getElementAt(int index) {
			return items.get(index);
		}
		
		void setItems(String[] strings) {
			fireIntervalRemoved(this, 0, items.size());
			items = new ArrayList<String>(Arrays.asList(strings));
			fireIntervalAdded(this, 0, items.size());
			if (items.size() > 0) {
				setSelectedItem(items.get(0));
			}
		}
		
		String[] getItems() {
			return items.toArray(new String[items.size()]);
		}
		
		void add(String string) {
			int index = items.size();
			items.add(string);
			fireIntervalAdded(this, index, index);
		}
		
		void removeAll() {
			int size = items.size();
			if (size > 0) {
				items.clear();
				fireIntervalRemoved(this, 0, size - 1);
			}
		}

	}

	public void addSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}

	public String getText() {
		return (String) combo.getSelectedItem();
	}

	public void setText(String string) {
		combo.setSelectedItem(string);
	}

	public void removeAll() {
		model.removeAll();
	}


}
