/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.io.File;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;

import org.eclipse.swt.SWT;

public class FileDialog extends Dialog {
	
	JFileChooser fileChooser;
	
	private String[] names;
	private String[] extensions;
	private String path;
	private String name;

	public FileDialog(Shell parent, int style) {
		super(parent, style);
		fileChooser = new JFileChooser();
	}

	public void setFilterNames(String[] names) {
		this.names = names;
	}

	public void setFilterExtensions(String[] extensions) {
		this.extensions = extensions;
	}

	public String getFilterPath() {
		return path;
	}
	
	public void setFilterPath(String path) {
		this.path = path;
	}
	
	public String getFileName() {
		return name;
	}

	public void setFileName(String name) {
		this.name = name;
	}

	public String open() {
		setupFilters();
		if (path != null && name != null) {
			fileChooser.setSelectedFile(new File(path, name));
		}
		int result;
		if ((style & SWT.OPEN) == SWT.OPEN) {
			result = fileChooser.showOpenDialog(parent.window.window());
		} else if ((style & SWT.SAVE) == SWT.SAVE) {
			result = fileChooser.showSaveDialog(parent.window.window());
		} else {
			throw new Error("unknown style");
		}
		if (result == JFileChooser.CANCEL_OPTION) {
			path = "";
			name = "";
			return null;
		}
		path = fileChooser.getSelectedFile().getPath();
		name = fileChooser.getSelectedFile().getName();
		return fileChooser.getSelectedFile().getAbsolutePath();
	}

	private void setupFilters() {
		fileChooser.resetChoosableFileFilters();
		if (names != null && extensions != null) {
			fileChooser.removeChoosableFileFilter(fileChooser.getAcceptAllFileFilter());
			for (int i = 0; i < names.length; i++) {
				final int index = i;
				fileChooser.addChoosableFileFilter(new FileFilter() {
					boolean windows = System.getProperty("os.name").indexOf("Windows") != -1;
					@Override
					public String getDescription() {
						return names[index];
					}
					@Override
					public boolean accept(File f) {
						String ext = extensions[index];
						if (f.isDirectory() || "*.*".equals(ext) || "*".equals(ext)) {
							return true;
						}
						ext = ext.replaceAll("\\.", "\\\\.").replaceAll("\\*", ".*");
						if (windows) {
							return f.getName().toUpperCase().matches(ext.toUpperCase());
						}
						return f.getName().matches(ext);
					}
				});
			}
			fileChooser.setFileFilter(fileChooser.getChoosableFileFilters()[0]);
		}
	}

}
