/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Container;

import javax.swing.BorderFactory;
import javax.swing.JLabel;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.graphics.Point;

public class Label extends Control {
	
	JLabel label;
	
	public Label(Composite composite, int style) {
		super(composite, style);
		label = new JLabel();
		if (_isSet(style, SWT.CENTER)) {
			label.setHorizontalAlignment(JLabel.CENTER);
		} else if (_isSet(style, SWT.RIGHT)) {
			label.setHorizontalAlignment(JLabel.RIGHT);
		}
		if (_isSet(style, SWT.BORDER)) {
			label.setBorder(BorderFactory.createEtchedBorder());
		}
		composite._add(this);
	}

	public String getText() {
		if (_isSet(style, SWT.WRAP)) {
			return label.getText().substring(6);
		}
		return label.getText();
	}

	public void setText(String text) {
		if (_isSet(style, SWT.WRAP)) {
			text = "<html>" + text;
		}
		int a = text.indexOf('&');
		if (a != -1) {
			text = text.substring(0, a) + text.substring(a + 1);
		}
		label.setText(text);
		label.setDisplayedMnemonicIndex(a);
		label.setIcon(null);
	}
	
	@Override
	Container _control() {
		return label;
	}

	public void setImage(Image image) {
		label.setIcon(image._icon());
		label.setText(null);
	}
	
	@Override
	public Point computeSize(int widthHint, int heightHint, boolean flushCache) {
		Point size = super.computeSize(widthHint, heightHint, flushCache);
		if (size.x == 0) size.x = DEFAULT_HEIGHT;
		if (size.y == 0) size.y = DEFAULT_HEIGHT;
		return size;
	}
}
