/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Container;
import java.awt.Cursor;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionAdapter;

import javax.swing.JLabel;
import javax.swing.text.BadLocationException;
import javax.swing.text.Element;
import javax.swing.text.Position;
import javax.swing.text.SimpleAttributeSet;
import javax.swing.text.View;
import javax.swing.text.html.HTML;
import javax.swing.text.html.HTMLDocument;

import org.eclipse.swt.SWT;

public class Link extends Control {
	
	JLabel link;
	
	public Link(Composite composite, int style) {
		super(composite, style);
		link = new JLabel();
		composite._add(this);
	}

	public void setText(String text) {
		link.setText("<html>" + text.replaceAll("\\<[Aa]\\>", "<a href=\"\">"));
		
		link.addMouseMotionListener(new MouseMotionAdapter() {
			@Override
			public void mouseMoved(MouseEvent e) {
				int x = e.getX() + link.getX();
				int y = e.getY() + link.getY();
				View view = (View) link.getClientProperty("html");
				y -= (link.getHeight() - (int) view.getPreferredSpan(View.Y_AXIS)) / 2;
				int pos = view.viewToModel(x, y, link.getBounds(), new Position.Bias[1]);
				if (pos != -1) {
					Element el = ((HTMLDocument) view.getDocument()).getCharacterElement(pos);
					SimpleAttributeSet a = (SimpleAttributeSet) el.getAttributes().getAttribute(HTML.Tag.A);
					if (a != null) {
						link.setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
						return;
					}
				}
				link.setCursor(null);
			}
		});
		
		link.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {
				int x = e.getX() + link.getX();
				int y = e.getY() + link.getY();
				View view = (View) link.getClientProperty("html");
				y -= (link.getHeight() - (int) view.getPreferredSpan(View.Y_AXIS)) / 2;
				int pos = view.viewToModel(x, y, link.getBounds(), new Position.Bias[1]);
				if (pos != -1) {
					Element el = ((HTMLDocument) view.getDocument()).getCharacterElement(pos);
					SimpleAttributeSet a = (SimpleAttributeSet) el.getAttributes().getAttribute(HTML.Tag.A);
					if (a != null) {
						String href = (String) a.getAttribute(HTML.Attribute.HREF);
						if (href.length() == 0) {
							try {
								href = el.getDocument().getText(el.getStartOffset(), el.getEndOffset() - el.getStartOffset());
							} catch (BadLocationException ex) {
								throw new Error(ex);
							}
						}
						fireHyperlink(href);
					}
				}
			}

			private void fireHyperlink(String href) {
				Event e = new Event();
				e.type = SWT.Selection;
				e.display = display;
				e.widget = Link.this;
				e.text = href;
				sendEvent(e);
			}
		});
	}
	
	@Override
	Container _control() {
		return link;
	}
}
