/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.util.ArrayList;

import javax.swing.AbstractListModel;
import javax.swing.JList;
import javax.swing.ListSelectionModel;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;

import org.eclipse.swt.SWT;

public class List extends Scrollable {
	
	JList list;
	
	public List(Composite parent, int style) {
		super(parent, style);
		list = new JList(new SWTListModel());
		if (!_isSet(style, SWT.MULTI)) {
			list.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		}
		list.getSelectionModel().addListSelectionListener(new ListSelectionListener() {
			public void valueChanged(ListSelectionEvent e) {
				sendEvent(SWT.Selection);
			}
		});
		list.addMouseListener(new MouseAdapter() {
			public void mouseClicked(MouseEvent e) {
				if (e.getClickCount() == 2) {
					sendEvent(SWT.DefaultSelection);
				}
			}
		});
		_init(list, style);
		parent._add(this);
	}

	public void add(String item) {
		((SWTListModel) list.getModel()).add(item);
	}

	public void setItems(String[] items) {
		((SWTListModel) list.getModel()).setItems(items);
	}

	public int[] getSelectionIndices() {
		return list.getSelectedIndices();
	}
	
	// sma's extensions
	
	class SWTListModel extends AbstractListModel {

		private static final long serialVersionUID = 7027783632108641315L;
		
		private java.util.List<String> items = new ArrayList<String>();
		
		void add(String item) {
			add(items.size(), item);
		}
		
		void add(int index, String item) {
			items.add(item);
			fireIntervalAdded(this, index, index);
		}
		
		void setItems(String[] items) {
			fireIntervalRemoved(this, 0, this.items.size());
			this.items = new ArrayList<String>(items.length);
			for (int i = 0; i < items.length; i++) {
				this.items.add(items[i]);
			}
			fireIntervalAdded(this, 0, this.items.size());
		}
		

		public int getSize() {
			return items.size();
		}

		public Object getElementAt(int index) {
			return items.get(index);
		}
	}

}
