/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.util.ArrayList;
import java.util.List;

import javax.swing.JComponent;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JPopupMenu;
import javax.swing.event.PopupMenuEvent;
import javax.swing.event.PopupMenuListener;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MenuListener;

public class Menu extends Widget {
	
	Shell parent;
	
	List<MenuItem> items = new ArrayList<MenuItem>();
	
	// JMenuBar if style == SWT.BAR,
	// JMenu if style == SWT.DROP_DOWN
	// JPopupMenu if style == SWT.POP_UP
	JComponent component; 
	
	/**
	 * Constructs a popup menu for the given control.
	 */
	public Menu(Control parent) {
		this(parent.menuShell(), SWT.POP_UP);
	}
	
	/**
	 * Constructs a new menu bar, pulldown menu or popup menu.
	 */
	public Menu(Shell parent, int style) {
		super(parent, style);
		this.parent = parent;
		if ((style & SWT.BAR) == SWT.BAR) {
			component = new JMenuBar();
		} else if ((style & SWT.DROP_DOWN) == SWT.DROP_DOWN) {
			component = new JMenu();
			awtListener(((JMenu) component).getPopupMenu());
		} else if ((style & SWT.POP_UP) == SWT.POP_UP) {
			component = new JPopupMenu();
			awtListener((JPopupMenu) component);
		} else {
			throw new UnsupportedOperationException();
		}
	}

	/**
	 * Constructs a new dropdown menu as submenu of the given menu.
	 */
	public Menu(Menu parent) {
		this(parent.parent, SWT.DROP_DOWN);
	}
	
	// called by MenuItem to add itself
	void add(MenuItem item) {
		items.add(item);
		component.add(item.component);
	}
	
	// called by MenuItem to remove itself
	void remove(MenuItem item) {
		items.remove(item);
		component.remove(item.component);
	}

	public void setLocation(int x, int y) {
		// TODO Auto-generated method stub
	}

	public void setVisible(boolean b) {
		// TODO Auto-generated method stub
	}

	public MenuItem[] getItems() {
		return items.toArray(new MenuItem[items.size()]);
	}

	public void addMenuListener(MenuListener listener) {
		checkWidget();
		if (listener == null) error(SWT.ERROR_NULL_ARGUMENT);
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Hide, typedListener);
		addListener(SWT.Show, typedListener);
	}
	
	void awtListener(JPopupMenu menu) {
		menu.addPopupMenuListener(new PopupMenuListener() {
			public void popupMenuCanceled(PopupMenuEvent e) {
			}
		
			public void popupMenuWillBecomeInvisible(PopupMenuEvent e) {
				sendEvent(SWT.Hide);
			}
		
			public void popupMenuWillBecomeVisible(PopupMenuEvent e) {
				sendEvent(SWT.Show);
			}
		});
	}
}
