/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Container;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JComponent;
import javax.swing.JMenu;
import javax.swing.JMenuItem;
import javax.swing.JSeparator;
import javax.swing.KeyStroke;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;

public class MenuItem extends Item {
	
	Menu parent;
	
	// JMenu if style == SWT.CASCADE
	// JSeparator if style == SWT.SEPARATOR
	// JMenuItem otherwise
	JComponent component;
	
	public MenuItem(final Menu parent, int style) {
		super(parent, style);
		this.parent = parent;
		if ((style & SWT.CASCADE) == SWT.CASCADE) {
			// need to add the menu from setMenu later
			component = new JMenuItem(); // to store the text/image
		} else if ((style & SWT.SEPARATOR) == SWT.SEPARATOR) {
			component = new JSeparator();
		} else {
			component = new JMenuItem();
			((JMenuItem) component).addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					sendEvent(SWT.Selection);
				}
			});
		}
		parent.add(this);
	}
	
	@Override
	public void dispose() {
		super.dispose();
		parent.remove(this);
	}
	
	@Override
	public void setText(String string) {
		super.setText(string);
		if (component instanceof JMenuItem) {
			JMenuItem item = (JMenuItem) component;
			int t = text.indexOf('\t');
			if (t != -1) {
				string = string.substring(0, t);
			}
			int a = text.indexOf('&');
			if (a != -1) {
				string = string.substring(0, a) + string.substring(a + 1);
				item.setMnemonic(string.charAt(a));
			}
			item.setText(string);
			item.setDisplayedMnemonicIndex(a);
		}
	}

	public void setMenu(Menu menu) {
		JMenu m = (JMenu) menu.component;
		JMenuItem mi = (JMenuItem) component;
		m.setText(mi.getText());
		m.setMnemonic(mi.getMnemonic());
		m.setDisplayedMnemonicIndex(mi.getDisplayedMnemonicIndex());
		Container c = component.getParent();
		for (int i = 0; i < c.getComponentCount(); i++) {
			if (c.getComponent(i) == component) {
				c.add(m, i);
				c.remove(i + 1);
				component = m;
				return;
			}
		}
		throw new Error();
	}

	public void setAccelerator(int accelerator) {
		if ((style & SWT.CASCADE) == SWT.CASCADE) {
			return;
		}
		JMenuItem item = (JMenuItem) component;
		if ((accelerator & SWT.CTRL) == SWT.CTRL || (accelerator & SWT.MOD1) == SWT.MOD1) {
			item.setAccelerator(KeyStroke.getKeyStroke("control " + (char) (accelerator & 0xffff)));
		}
	}

	public void addSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) error(SWT.ERROR_NULL_ARGUMENT);
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}

	public void setEnabled(boolean enabled) {
		component.setEnabled(enabled);
	}

	public boolean getSelection() {
		return ((JMenuItem) component).isSelected();
	}

	public void setSelection(boolean selection) {
		((JMenuItem) component).setSelected(selection);
	}

	
}
