/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import javax.swing.JOptionPane;

import org.eclipse.swt.SWT;

public class MessageBox extends Dialog {
	
	static final int OK = SWT.OK;
	static final int OK_CANCEL = OK | SWT.CANCEL;
	static final int YES_NO = SWT.YES | SWT.NO;
	static final int YES_NO_CANCEL = YES_NO | SWT.CANCEL;
	
	String text;
	String message;

	public MessageBox(Shell parent, int style) {
		super(parent, style);
	}

	public void setText(String text) {
		this.text = text;
	}

	public void setMessage(String message) {
		this.message = message;
	}

	public int open() {
		if (isType(OK_CANCEL)) {
			int result = JOptionPane.showConfirmDialog(
					parent.container,
					message,
					text,
					JOptionPane.OK_CANCEL_OPTION,
					messageType());
			switch (result) {
			case JOptionPane.OK_OPTION:
				return SWT.OK;
			default:
				return SWT.CANCEL;
			}
		}
		if (isType(YES_NO) || isType(YES_NO_CANCEL)) {
			int result = JOptionPane.showConfirmDialog(
					parent.container,
					message,
					text,
					isType(YES_NO_CANCEL) ? JOptionPane.YES_NO_CANCEL_OPTION : JOptionPane.YES_NO_OPTION,
					messageType());
			switch (result) {
			case JOptionPane.YES_OPTION:
				return SWT.YES;
			case JOptionPane.NO_OPTION:
				return SWT.NO;
			default:
				return SWT.CANCEL;
			}
		}
		JOptionPane.showMessageDialog(
				parent.container, 
				message, 
				text, 
				messageType());
		return SWT.OK;
	}
	
	boolean isType(int type) {
		return isSet(type);
	}

	int messageType() {
		if (isSet(SWT.ICON_ERROR)) {
			return JOptionPane.ERROR_MESSAGE;
		} else if (isSet(SWT.ICON_WARNING)) {
			return JOptionPane.WARNING_MESSAGE;
		} else if (isSet(SWT.ICON_QUESTION)) {
			return JOptionPane.QUESTION_MESSAGE;
		} else if (isSet(SWT.ICON_INFORMATION)) {
			return JOptionPane.INFORMATION_MESSAGE;
		}
		return JOptionPane.PLAIN_MESSAGE;
	}
		
	boolean isSet(int bits) {
		return (style & bits) == bits;
	}
}
