/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Container;

import javax.swing.JSlider;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;

public class Scale extends Control {
	
	// TODO implement Selection and DefaultSelection events
	
	JSlider scale;

	public Scale(Composite parent, int style) {
		super(parent, style);
		scale = new JSlider();
		scale.setPaintTicks(true);
		scale.setPaintTrack(true);
		parent._add(this);
	}

	@Override
	Container _control() {
		return scale;
	}
	
	public int getMaximum() {
		return scale.getMaximum();
	}

	public void setMaximum(int value) {
		scale.setMaximum(value);
	}
	
	public int getSelection() {
		return scale.getValue();
	}
	
	public void setSelection(int value) {
		scale.setValue(value);
	}

	public void setIncrement(int increment) {
		scale.setMinorTickSpacing(increment); // TODO this is wrong?!
	}

	public void setPageIncrement(int pageIncrement) {
		scale.setMajorTickSpacing(pageIncrement); // TODO this is wrong?!
	}

	public void addSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}

	public void removeSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		if (eventTable != null) {
			eventTable.unhook(SWT.Selection, listener);
			eventTable.unhook(SWT.DefaultSelection, listener);
		}
	}

}
