/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.Component;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.table.AbstractTableModel;
import javax.swing.table.DefaultTableCellRenderer;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.MouseAdapter;
import org.eclipse.swt.events.MouseListener;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Point;

public class Table extends Composite {
	
	JTable table;
	SWTTableModel model;

	public Table(Composite parent, int style) {
		super(parent, style, 1);
		table = new JTable(model = new SWTTableModel());
		if (_isSet(style, SWT.SINGLE)) {
			table.getSelectionModel().setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		}
		table.setShowGrid(false);
		table.setDefaultRenderer(Object.class, new DefaultTableCellRenderer() {
			private static final long serialVersionUID = -4985121311320978707L;

			@Override
			public Component getTableCellRendererComponent(JTable table, Object value, boolean isSelected,
					boolean hasFocus, int row, int column) {
				JLabel label = (JLabel) super.getTableCellRendererComponent(table, value, isSelected, hasFocus, row, column);
				if (column == 0 && model.items.get(row).getImage() != null) {
					label.setIcon(model.items.get(row).getImage()._icon());
				} else {
					label.setIcon(null);
				}
				return label;
			}
		});
		_init(table, style);
		parent._add(this);
	}

	public void setHeaderVisible(boolean visible) {
		// TODO Auto-generated method stub
	}
	
	public void setLinesVisible(boolean visible) {
		table.setShowGrid(visible);
	}

	public TableItem[] getItems() {
		return model.items.toArray(new TableItem[model.items.size()]);
	}
	
	// sma's extensions...
	
	static class SWTTableModel extends AbstractTableModel {
		
		private static final long serialVersionUID = 6704284677162560366L;

		private List<TableColumn> columns = new ArrayList<TableColumn>();
		
		private List<TableItem> items = new ArrayList<TableItem>();

		public int getRowCount() {
			return items.size();
		}

		public int getColumnCount() {
			return columns.size();
		}

		public String getColumnName(int columnIndex) {
			return columns.get(columnIndex).text;
		}

		public Class<?> getColumnClass(int columnIndex) {
			return String.class;
		}

		public Object getValueAt(int rowIndex, int columnIndex) {
			return items.get(rowIndex).getText(columnIndex);
		}
		
		void add(TableItem item) {
			add(items.size(), item);
		}
		
		void add(int index, TableItem item) {
			items.add(index, item);
			fireTableRowsInserted(index, index);
		}
		
		void remove(TableItem item) {
			int index = items.indexOf(item);
			if (index != -1) {
				items.remove(index);
				fireTableRowsDeleted(index, index);
			}
		}

		public int add(TableColumn column) {
			columns.add(column);
			return columns.size() - 1;
		}
		
		void removeAll() {
			int size = items.size();
			if (size > 0) {
				items.clear();
				fireTableRowsDeleted(0, size - 1);
			}
		}
	}
	
	// end...

	public TableColumn getColumn(int index) {
		return model.columns.get(index);
	}

	public TableItem getItem(Point pt) {
		// TODO Auto-generated method stub
		return null;
	}

	public int indexOf(TableItem item) {
		return model.items.indexOf(item);
	}

	public int getColumnCount() {
		return model.columns.size();
	}

	public int getSelectionCount() {
		return table.getSelectedRowCount();
	}

	public TableItem[] getSelection() {
		int[] indices = table.getSelectedRows();
		TableItem[] items = new TableItem[indices.length];
		for (int i = 0; i < indices.length; i++) {
			items[i] = model.items.get(indices[i]);
		}
		return items;
	}

	public int getItemCount() {
		return model.items.size();
	}

	public TableItem getItem(int index) {
		return model.items.get(index);
	}

	public int getSelectionIndex() {
		return table.getSelectedRow();
	}

	public void setSelection(int index) {
		table.getSelectionModel().setSelectionInterval(index, index);
	}

	public int[] getSelectionIndices() {
		return table.getSelectedRows();
	}
	
	public void addSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}
	
	public void removeSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		if (eventTable != null) {
			eventTable.unhook(SWT.Selection, listener);
			eventTable.unhook(SWT.DefaultSelection, listener);
		}
	}

	public void removeAll() {
		model.removeAll();
	}

	public void showSelection() {
		// TODO Auto-generated method stub
	}

	//TODO move up
	public void addMouseListener(MouseListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.MouseDown, typedListener);
		addListener(SWT.MouseUp, typedListener);
		addListener(SWT.MouseDoubleClick, typedListener);
	}

	public void remove(int[] indices) {
		for (int i = indices.length - 1; i >= 0; --i) {
			model.remove(model.items.get(indices[i]));
		}
	}

}
