/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Rectangle;

public class TableItem extends Item {
	
	Table parent;
	
	String[] strings;

	public TableItem(Table parent, int style) {
		super(parent, style);
		this.parent = parent;
		this.parent.model.add(this);
	}

	public TableItem(Table parent, int style, int index) {
		super(parent, style);
		this.parent = parent;
		this.parent.model.add(index, this);
	}
	
	@Override
	public void setText(String string) {
		setText(new String[] { string });
	}

	public void setText(String[] strings) {
		this.strings = strings;
		_updateColumns();
	}

	public String getText(int index) {
		return strings == null ? null : strings[index];
	}
	
	public void dispose() {
		parent.model.remove(this);
		super.dispose();
	}

	public void setText(int index, String text) {
		if (strings == null) {
			strings = new String[index + 1];
		}  else if (strings.length <= index) {
			String[] nstrings = new String[index + 1];
			System.arraycopy(strings, 0, nstrings, 0, strings.length);
			strings = nstrings;
		}
		strings[index] = text;
		_updateColumns();
	}

	public Rectangle getBounds(int index) {
		// TODO Auto-generated method stub
		return null;
	}
	
	void _updateColumns() {
		while (strings.length > parent.model.getColumnCount()) {
			parent.model.add(new TableColumn(parent, SWT.NONE));
		}
	}

	public Rectangle getImageBounds(int column) {
		if (image == null) {
			return new Rectangle(0, 0, 0, 0);
		}
		return image.getBounds();
	}

}
