/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

import javax.swing.JTextArea;
import javax.swing.JTextField;
import javax.swing.event.DocumentEvent;
import javax.swing.event.DocumentListener;
import javax.swing.text.JTextComponent;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.events.SelectionListener;

public class Text extends Scrollable {
	
	JTextComponent text;

	public Text(Composite parent, int style) {
		super(parent, style);
		if (_isSet(style, SWT.SINGLE)) {
			text = new JTextField();
			container = text;
		} else {
			text = new JTextArea();
			_init(text, style);
		}
		text.getDocument().addDocumentListener(new DocumentListener() {
			public void changedUpdate(DocumentEvent e) {
				sendEvent(SWT.Modify);
			}
		
			public void removeUpdate(DocumentEvent e) {
				sendEvent(SWT.Modify);
			}
		
			public void insertUpdate(DocumentEvent e) {
				sendEvent(SWT.Modify);
			}
		});
		text.addKeyListener(new KeyAdapter() {
			@Override
			public void keyTyped(KeyEvent evt) {
				if (evt.getKeyChar() == KeyEvent.VK_ENTER) {
					sendEvent(SWT.DefaultSelection);
				}
			}
		});
		parent._add(this);
	}
	
	public String getSelectionText() {
		return text.getSelectedText();
	}

	public void insert(String string) {
		text.replaceSelection(string);
	}

	public String getText() {
		return text.getText();
	}

	public void setText(String string) {
		text.setText(string);
	}

	public void addModifyListener(ModifyListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Modify, typedListener);
	}
	
	public void removeModifyListener(ModifyListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		if (eventTable != null) {
			eventTable.unhook(SWT.Modify, listener);
		}
	}
	
	public void addSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}

	public void removeSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		if (eventTable != null) {
			eventTable.unhook(SWT.Selection, listener);
			eventTable.unhook(SWT.DefaultSelection, listener);
		}
	}
	
	public int getCharCount() {
		return text.getDocument().getLength();
	}

	public void append(String string) {
		if (text instanceof JTextArea) {
			((JTextArea) text).append(string);
		} else {
			text.setText(text.getText() + string);
		}
	}

	public void setSelection(int position) {
		text.setCaretPosition(position);
	}

	public int getCaretLocation() {
		return text.getCaretPosition();
	}

	public void setSelection(int start, int end) {
		text.select(start, end);
	}
	
	public void selectAll() {
		text.selectAll();
	}
	
	public void cut() {
		text.cut();
	}
	
	public void copy() {
		text.copy();
	}
	
	public void paste() {
		text.paste();
	}

}
