/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JComponent;
import javax.swing.JSeparator;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionListener;
import org.eclipse.swt.graphics.Image;

public class ToolItem extends Item {
	
	ToolBar parent;

	JComponent component;

	public ToolItem(ToolBar parent, int style) {
		super(parent, style);
		if ((style & SWT.SEPARATOR) != 0) {
			component = new JSeparator();
		} else {
			JButton button = new JButton();
			button.setRolloverEnabled(true);
			button.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					sendEvent(SWT.Selection);
				}
			});
			component = button;
		}		
		parent.add(this);
	}
	
	@Override
	public void setText(String string) {
		super.setText(string);
		JButton button = (JButton) component;
		button.setText(text);
		button.setIcon(null);
	}
	
	@Override
	public void setImage(Image image) {
		super.setImage(image);
		JButton button = (JButton) component;
		button.setIcon(image._icon());
		button.setText(null);
	}

	public void setToolTipText(String string) {
		component.setToolTipText(string);
	}

	public void addSelectionListener(SelectionListener listener) {
		checkWidget();
		if (listener == null) {
			error(SWT.ERROR_NULL_ARGUMENT);
		}
		TypedListener typedListener = new TypedListener(listener);
		addListener(SWT.Selection, typedListener);
		addListener(SWT.DefaultSelection, typedListener);
	}

}
