/*******************************************************************************
 * Copyright (c) 2005 Stefan Matthias Aust.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Stefan Matthias Aust - initial implementation
 *******************************************************************************/
package org.eclipse.swt.widgets;

import javax.swing.Icon;
import javax.swing.tree.DefaultMutableTreeNode;
import javax.swing.tree.DefaultTreeModel;
import javax.swing.tree.MutableTreeNode;

import org.eclipse.swt.graphics.Image;

public class TreeItem extends Item {
	
	Tree parent;
	
	MutableTreeNode node;

	public TreeItem(Tree parent, int style) {
		this(parent, style, parent.root.getChildCount());
	}

	public TreeItem(Tree parent, int style, int index) {
		super(parent, style);
		this.parent = parent;
		parent.root.insert(node = new DefaultMutableTreeNode(this, true), index);
		_model().reload(parent.root);
	}
	
	public TreeItem(TreeItem parentItem, int style) {
		this(parentItem, style, parentItem.node.getChildCount());
	}

	public TreeItem(TreeItem parentItem, int style, int index) {
		super(parentItem.parent, style);
		this.parent = parentItem.parent;
		parentItem.node.insert(node = new DefaultMutableTreeNode(this), index);
	}

	public TreeItem[] getItems() {
		TreeItem[] items = new TreeItem[node.getChildCount()];
		for (int i = 0; i < items.length; i++) {
			items[i] = (TreeItem) ((DefaultMutableTreeNode) node.getChildAt(i)).getUserObject();
		}
		return items;
	}
	
	@Override
	public String getText() {
		if (isDisposed()) return null;
		return super.getText();
	}
	
	@Override
	public void setText(String string) {
		super.setText(string);
		_model().nodeChanged(node);				
	}
	
	@Override
	public void setImage(Image image) {
		super.setImage(image);
		_model().nodeChanged(node);
	}
	
	@Override
	public void dispose() {
		_model().removeNodeFromParent(node);
		node = null;
		super.dispose();
	}
	
	DefaultTreeModel _model() {
		return (DefaultTreeModel) parent.tree.getModel();
	}
	
	Icon _icon() {
		if (isDisposed()) return null;
		return getImage() == null ? null : getImage()._icon();
	}

	public boolean getExpanded() {
		return parent.tree.isExpanded(parent.indexOf(this));
	}

	public void setExpanded(boolean expanded) {
		parent.tree.expandRow(parent.indexOf(this));
	}

	
}
